Crate json_escape_simd

Crate json_escape_simd 

Optimized SIMD routines for escaping JSON strings.

Thin facade over escape_simd::json. The implementation is from sonic-rs; we only take the string escaping part to avoid the abstraction overhead.

Functions

escape
Escapes value as a JSON string, including the surrounding " quotes.
escape_into
Escapes value (including the surrounding ") and appends the result to dst, growing dst as needed.